summaryrefslogtreecommitdiff
path: root/lisp/progmodes/ebnf-otz.el
diff options
context:
space:
mode:
authorJuanma Barranquero <lekktu@gmail.com>2003-02-10 09:55:17 +0000
committerJuanma Barranquero <lekktu@gmail.com>2003-02-10 09:55:17 +0000
commit18ac078250f9450f8970f48efcdb72cf0e506414 (patch)
treef937781d3ac05e9fce932129970a838ec9a5317c /lisp/progmodes/ebnf-otz.el
parentce4254bd12176593c718298c36bedbc816d57109 (diff)
downloademacs-18ac078250f9450f8970f48efcdb72cf0e506414.tar.gz
(ebnf-optimize, ebnf-optimize1): Fix typo.
Diffstat (limited to 'lisp/progmodes/ebnf-otz.el')
-rw-r--r--lisp/progmodes/ebnf-otz.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/lisp/progmodes/ebnf-otz.el b/lisp/progmodes/ebnf-otz.el
index 4a6f24101d5..73f1ce9238c 100644
--- a/lisp/progmodes/ebnf-otz.el
+++ b/lisp/progmodes/ebnf-otz.el
@@ -1,11 +1,11 @@
;;; ebnf-otz.el --- syntatic chart OpTimiZer
;; Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
;; Author: Vinicius Jose Latorre <vinicius@cpqd.com.br>
;; Maintainer: Vinicius Jose Latorre <vinicius@cpqd.com.br>
;; Keywords: wp, ebnf, PostScript
-;; Time-stamp: <2001/08/15 17:13:25 vinicius>
+;; Time-stamp: <2003-02-10 10:46:51 jbarranquero>
;; Version: 1.0
;; This file is part of GNU Emacs.
@@ -196,7 +196,7 @@
;; A = B | C A D. ==> A = B | C A D.
(defun ebnf-optimize (syntax-list)
- "Syntatic chart optimizer."
+ "Syntactic chart optimizer."
(if (not ebnf-optimize)
syntax-list
(let ((ebnf-total (length syntax-list))
@@ -225,7 +225,7 @@
;; 10. A = B C E | B D E. ==> A = B (C | D) E.
(defun ebnf-optimize1 (prod)
- (ebnf-message-info "Optimizing syntatic chart")
+ (ebnf-message-info "Optimizing syntactic chart")
(let ((production (ebnf-node-production prod)))
(and (eq (ebnf-node-kind production) 'ebnf-generate-alternative)
(let* ((hlist (ebnf-split-header-prefix
@@ -1,11 +1,11 @@
-;;; ebnf-otz.el --- syntatic chart OpTimiZer
+;;; ebnf-otz.el --- syntactic chart OpTimiZer
;; Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
;; Author: Vinicius Jose Latorre <vinicius@cpqd.com.br>